# -*- coding: utf-8 -*-

from django.conf.urls import include, url
from django.contrib import admin

urlpatterns = [
    url(r'^admin/', include(admin.site.urls)),

    url(r'^', include('demo.urls',
        app_name='demo', namespace='demo')),
]



# -*- coding: utf-8 -*-

from django.conf.urls import patterns, include, url
from django.views.generic import TemplateView

urlpatterns = patterns('',
    url(r'^', TemplateView.as_view(template_name='home.html'),
        name='home'),
)



# -*- coding: utf-8 -*-

import codecs
from datetime import datetime
import os

import urllib2
from bs4 import BeautifulSoup

from real_content.settings import DRC_LANGUAGE


def get_language(language=''):
    u"""
    Gets language from settings if it wasn't explicitly provided.
    """
    if language == '' or language is None:
        language = DRC_LANGUAGE
    language = language.lower().strip()
    return language


def get_text_file(language, text_type='titles', file_open_mode='r'):
    u"""
    Gets text file for specific language.
    Used for reading and writing to a file.
    """
    content_dir = os.path.abspath(
        os.path.join(os.path.dirname(__file__), 'content'))
    content_file_path = os.path.join(
        content_dir, '{}_{}.txt'.format(language, text_type))

    if os.path.exists(content_file_path) or 'a' in file_open_mode:
        content_file = codecs.open(content_file_path, file_open_mode, 'utf-8')
        return content_file
    else:
        return None


def save_content(content, tag, text_type='paragraphs', url='', language='',
    min_length=150):
    u"""
    Saves content to language file.
    """
    new_data = []

    for tag in content.find_all(tag):
        new_content = ' '.join(
            [part.strip() for part in tag.getText().split('\n')]).strip()

        if len(new_content) > min_length:
            new_data.append(new_content)

    # getting rid of duplicates in new data
    new_data = list(set(new_data))

    # remove previously existing items from new data
    existing_file = get_text_file(language, text_type, 'r')
    if existing_file:
        existing_data = existing_file.read().splitlines()
    else:
        existing_data = []

    new_data_copy = new_data[:]
    for text in new_data_copy:
        if text in existing_data:
            new_data.remove(text)

    # put date and source as comments at the beginning of new data
    if len(new_data) > 0:
        new_data.insert(0, '# {}'.format(url))
        new_data.insert(0, '# {}'.format(datetime.now().isoformat()))

    # write line from new_data one by one into local file
    with get_text_file(language, text_type, 'a') as text_file:
        for new_content in new_data:
            text_file.write(u'{}\n'.format(new_content))
        text_file.write(u'\n')


def parse_url(url, language=''):
    u"""
    Getting url, parsing it and saving the contents of it to local files.
    """
    language = get_language(language)
    try:
        soup = BeautifulSoup(urllib2.urlopen(url).read())

        # saving paragraphs
        save_content(soup, 'p', 'paragraphs', url=url, language=language,
            min_length=150)

        # saving all headings
        for i in range(1, 7):
            heading_level = 'h{0}'.format(i)
            save_content(soup, heading_level, 'titles', url=url,
                language=language, min_length=20)
        return 'success!'

    except urllib2.HTTPError:
        return '403 error'



# -*- coding: utf-8 -*-

from optparse import make_option

from django.core.management import BaseCommand

from real_content.drc_utils import parse_url


class Command(BaseCommand):
    help = u"""
        Collect titles and paragraphs from given url.
        If no language is provided, it will use the one given in settings.

        Example:
        ./manage.py drc_addcontent -u http://www.24sata.hr/a-383985 -l hr
        """

    option_list = BaseCommand.option_list + (
        make_option('-u', '--url', action='store', dest='url',
            help=u'url to parse'),
        make_option('-l', '--language', action='store', dest='language',
            help=u'language of url'),
        )

    def handle(self, *args, **options):
        url = options.get('url', None)
        language = options.get('language', '')

        if url:
            parse_url(url, language)
        else:
            print('Enter url using "-u" option')



# -*- coding: utf-8 -*-

import random

from django import template

from real_content.drc_utils import get_language, get_text_file

register = template.Library()


def random_lines(text_file, no_of_lines=1):
    u"""
    Gets a random line from a file ignoring lines starting with #.
    """
    if text_file is None:
        return 'language file does not exists'
    lines = text_file.read().splitlines()
    clean_lines = [line for line in lines
        if line.startswith('#') is False or line.strip() == '']

    if clean_lines == []:
        return 'no usable lines in language file'
    if no_of_lines == 1:
        return random.choice(clean_lines)
    else:
        return random.sample(clean_lines, no_of_lines)


@register.inclusion_tag('real_content/tags/drc_title.html')
def drc_title(heading_level=1, css_class='', language=''):
    u"""
    Retrieve random title.
    Uses langauge from global settings if an override is not provided.
    """
    language = get_language(language)
    titles = get_text_file(language, 'titles')

    data = {
        'title': random_lines(titles, 1),
    }

    if heading_level > 6:
        data['heading_level'] = 6
    else:
        data['heading_level'] = heading_level
    data['css_class'] = css_class
    return data


@register.inclusion_tag('real_content/tags/drc_paragraph.html')
def drc_paragraphs(no_of_paraghaphs=1, css_class='', language=''):
    u"""
    Retrieve n random paragraphs.
    Uses langauge from global settings if an override is not provided.
    """
    language = get_language(language)
    paragraphs = get_text_file(language, 'paragraphs')

    data = {
        'paragraphs': random_lines(paragraphs, no_of_paraghaphs)
    }

    data['css_class'] = css_class
    return data


@register.inclusion_tag('real_content/tags/drc_lorempixel.html')
def drc_image(width=640, height=480, category='',
    gray=False, image_id='', css_class=''):
    u"""
    Retrieve image from lorempixel.com service.
    Possible categories are:
        abstract, animals, business, cats, city, food, nightlife, fashion,
        people, nature, sports, technics, transport
    """
    data = {}
    url = u'http://lorempixel.com/'
    if gray:
        url = '{url}g/'.format(url=url)
    url = '{url}{width}/{height}/'.format(url=url, width=width, height=height)
    if category:
        url = '{url}{category}/'.format(url=url, category=category)

        # image_id can only be defined if the category was set, otherwise we
        # get black image
        if image_id:
            url = '{url}{image_id}'.format(url=url, image_id=image_id)
        else:
            # use random image_id if non was set to prevent from displaying the
            # same image over and over again
            url = '{url}{image_id}'.format(
                url=url,
                image_id=random.randrange(1, 11))

    data['url'] = url
    data['css_class'] = css_class
    return data



# -*- coding: utf-8 -*-

import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name='django-real-content',
    version='0.1.1',
    packages=find_packages(),
    # packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    license='MIT',
    description='Template tags to quickly show real content instead of lorem ipsum.',
    long_description=README,
    url='https://github.com/mislavcimpersak/django-real-content',
    download_url='https://github.com/mislavcimpersak/django-real-content/tarball/0.1',
    author=u'Mislav Cimperšak',
    author_email='mislav.cimpersak@gmail.com',
    keywords='django real content lorem ipsum',
    install_requires=[
        'Django>=1.7',
        'beautifulsoup4>=4.3'
    ],
    # tests are on the roadmap
    # tests_require=[
    #     'Django>=1.7',
    # ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
